
/* 

Syntax for JFR-article: Transition to fatherhood and adjustments in working hours: The importance of organizational policy feedback //

// Lines 33-81		: Sample Selection of the longitudinal data (wave 1 to wave 3 already merged)
// Lines 84-116		: Comparison of missing sample & analytical sample (Table A2)
// Lines 117-133	: Descriptives of analytical sample, by birth (Table 1, Table A1)
// Lines 135-270	: Set of regressions for display in main body (Table 2; Figures 1 and 2) and appendix (Table A3)
// Lines 282-300	: Robustness check 1: Sample-Split by normalization of flexiplace in first observation of organizational (Table A4)
// Lines 302-455	: Robustness check 2: Sample-Split egalitarian gender beliefs (split by single items) (Table A5-A7)

*/


* Header 
clear all 			
capture log close 	
set more off 		
log using "XX", replace

display "$S_TIME  $S_DATE"

** Globals
global data 	 "XX"
global dofiles	 "XX"
global fgure  	 "XX"
global table  	 "XX"
global workdata  "XX"



** Sample selection

** use data 
use ${workdata}panel_paps_workinghours_jun23, clear


** define panel data 
	xtset paarnr year 

** exclude dropouts
	keep if sample < 3

** keep only men
	keep if sexid == 1 

** keep only partnered respondents 
	keep if partner == 1 

** keep if respondents 55 and younger
	keep if age <= 55

** keep only if respondent can be matched with an organization
	keep if betidL != .s  

	
** generating samplemiss based on regression (to examine who will be lost due to listwise deletion; 0 = analytical sample, 1 = missing sample due to listwise deletion)
	global time " c.c_exper_yr c.exper_yr2 i.year" 
	global famsit "ib3.marwork "
	global flex "c.O_heim i.jaheiman"

	xtreg jazuh i.birth2 $time $famsit $flex , fe i(paarnr) vce(robust)
	gen reg = 1 if e(sample)		//in the sample
	replace reg = 0 if reg != 1 	//not in the sample 	

	
    **How many observations to respondents provide? If there is only one observation in the analyses with reg == 1, then the persons are dropped; i.e. this one observation then also counts as reg == 0. 
	bysort paarnr: egen min_reg = min(reg)
	bysort paarnr: egen max_reg = max(reg) if reg <.
	bysort paarnr: egen mean_reg = mean(reg) if reg <.
	*if reg <0.6 means that person participated only in 1 wave
	replace reg = 0 if reg == 1 & mean_reg < 0.6 	//only one observation in the sample, will also be missing due to restriction N>=2
	
	//Also for participating individuals, only keep respondents with at least 2 observations 
	bysort paarnr: gen N = _N 
	keep if N >= 2 
	
	//based on information generate variable samplemiss 
	gen samplemiss = 1 if reg == 0  	//samplemiss = 1 if lost to listwise deletion
	replace samplemiss = 0 if reg == 1 //samplemiss = 0 if part of analytical sample
	

************************************************************************
************** DESCRIPTIVE ANALYSES ************************************
************************************************************************
	
** Sample Description by Missings for the Appendix
		
	
** Table A.2: descriptive table comparing characteristics analytical and missing sample
	//Generate dummy variables for each category of marwork and year for descriptive tables. 
	tab marwork, gen(marwork_d)
	tab year, gen(year_d)
	
	cd "xx"
	bysort samplemiss: asdoc sum birth2 jazuh jazouh jaheiman O_heim first_O_heim year_d* exper_yr marwork_d*  ,  dec(2) save(description_missings)
	
	
** Table A.2: Significance of differences between two samples 

		ttest exper_yr, by(samplemiss)
		ttest O_heim, by(samplemiss)
		ttest first_O_heim, by(samplemiss)
		ttest jaheiman, by(samplemiss) 
		ttest birth2, by(samplemiss) 
		ttest jazuh, by(samplemiss) 
		ttest jazouh, by(samplemiss) 
		ttest marwork_d1, by(samplemiss) 
		ttest marwork_d2, by(samplemiss) 
		ttest marwork_d3, by(samplemiss) 
		ttest marwork_d4, by(samplemiss) 
		ttest year_d1, by(samplemiss) 
		ttest year_d2, by(samplemiss) 
		ttest year_d3, by(samplemiss) 
		log close

	
	
** After comparison by samplemiss - only keep respondents that are part of the analytical sample (reg==1)
	keep if reg == 1 

** Table 1: descriptive statistics by birth for main body of text
	
	cd "xx"
	bysort birth2: asdoc sum birth2 jazuh jazouh birth2 jaheiman O_heim first_O_heim year_d* exper_yr marwork_d* if reg == 1,  dec(2) save(analytical_sample) //overall descriptives 
	asdoc sum birth2 jazuh jazouh birth2 jaheiman O_heim first_O_heim year_d* exper_yr marwork_d* if reg == 1,  dec(2) save(analytical_sample) // descriptives by childbirth 
	
** Table A.1: Correlations between organizational characteristics
	asdoc	pwcorr first_O_heim O_heim O_flex O_fam_engaged O_belastung  , sig dec(2) save(descript_corr)

	

************************************************************************
************** MuULTIVARIATE ANALYSES **********************************
************************************************************************

	
** 1. time invariant lagged variable for normalization of flexiplace

	// Time-invariant lagged - actual hours
	
	xtreg jazuh i.birth2  $time $famsit    , re vce(cluster paarnr)
	eststo tat3_re0

	xtreg jazuh i.birth2##c.c_first_O_heim  $time  $famsit   , re vce(cluster paarnr)
	eststo tat3_re

	xtreg jazuh i.birth2##c.c_first_O_heim  $time $famsit  , re vce(cluster paarnr)
	eststo tat4_re

	xtreg jazuh i.birth2  $time  $famsit   , fe vce(cluster paarnr)
	eststo tat3_fe0

	xtreg jazuh i.birth2##c.c_first_O_heim  $time  $famsit   , fe vce(cluster paarnr)
	eststo tat3_fe

	xtreg jazuh i.birth2##c.c_first_O_heim  $time $famsit  , fe vce(cluster paarnr)
	eststo tat4_fe

	// Time-invariant lagged - contracted hours

	xtreg jazouh i.birth2  $time  $famsit   , re vce(cluster paarnr)
	eststo ver3_re0

	xtreg jazouh i.birth2##c.c_first_O_heim  $time $famsit , re vce(cluster paarnr)
	eststo ver3_re

	xtreg jazouh i.birth2##c.c_first_O_heim  $time $famsit  , re vce(cluster paarnr)
	eststo ver4_re

	xtreg jazouh i.birth2  $time $famsit   , fe vce(cluster paarnr)
	eststo ver3_fe0

	xtreg jazouh i.birth2##c.c_first_O_heim  $time $famsit    , fe vce(cluster paarnr)
	eststo ver3_fe

	xtreg jazouh i.birth2##c.c_first_O_heim  $time $famsit  , fe vce(cluster paarnr)
	eststo ver4_fe


** 2. Time varying variable for for normalization of flexiplace


	// Time varying variable  - actual hours
	
	xtreg jazuh i.birth2 $time $famsit  if samplemiss == 0  , re vce(cluster paarnr)
	eststo tat0_re

	xtreg jazuh i.birth2##c.c_O_heim $time $famsit  if samplemiss == 0  , re vce(cluster paarnr)
	eststo tat1_re

	xtreg jazuh i.birth2##c.c_O_heim $time $famsit , re vce(cluster paarnr)
	eststo tat2_re

	xtreg jazuh i.birth2 $time $famsit  if samplemiss == 0  , fe vce(cluster paarnr)
	eststo tat0_fe

	xtreg jazuh i.birth2##c.c_O_heim   $time $famsit  if samplemiss == 0   , fe vce(cluster paarnr)
	eststo tat1_fe

	xtreg jazuh i.birth2##c.c_O_heim $time $famsit , fe vce(cluster paarnr)
	eststo tat2_fe


	// Time varying variable - contracted hours

	xtreg jazouh i.birth2  $time $famsit  , re vce(cluster paarnr)
	eststo ver0_re

	xtreg jazouh i.birth2##c.c_O_heim   $time $famsit  , re vce(cluster paarnr)
	eststo ver1_re

	xtreg jazouh i.birth2##c.c_O_heim $time $famsit $famsit , re vce(cluster paarnr)
	eststo ver2_re

	xtreg jazouh i.birth2  $time $famsit  , fe vce(cluster paarnr)
	eststo ver0_fe

	xtreg jazouh i.birth2##c.c_O_heim   $time $famsit  , fe vce(cluster paarnr)
	eststo ver1_fe

	xtreg jazouh i.birth2##c.c_O_heim $time $famsit , fe vce(cluster paarnr)
	eststo ver2_fe


** Table 2 (fixed effects Models) 

esttab tat0_fe tat3_fe tat1_fe ver3_fe0 ver3_fe ver1_fe using ${table}actualhours_flexiplace_fe.rtf, replace  label   /// 
		b(%10.3f)   ///
		nogaps nolines mtitles scalars(r2 r2_w r2_b r2_o)  ///
		compress ///
		star(+ 0.10 * 0.05 ** 0.01 *** 0.001)	
		

//Table A3 (random effects Models) 

esttab tat0_fe tat3_fe tat1_fe ver3_fe0 ver3_fe ver1_fe using ${table}actualhours_flexiplace_fe.rtf, replace  label   /// 
		b(%10.3f)   ///
		nogaps nolines mtitles scalars(r2 r2_w r2_b r2_o)  ///
		compress ///
		star(+ 0.10 * 0.05 ** 0.01 *** 0.001)	

		
		
** Figure 1 

xtreg jazuh i.birth2##c.O_heim $time $famsit , fe vce(cluster paarnr)

	margins r.birth2, at(O_heim=(0(10)100)) level(90) noestimcheck
	marginsplot, graphregion(color(white) lcolor(white)) scheme(s2mono) yline(0) title("")   ylabel (, labsize(small))  xlabel (, labsize(small)) ///
	plot1opts(lpattern(solid) lcolor(black) mcolor(black)) ci1opts(lcolor(gs7) lwidth(thin) mcolor(black))  ///
	ytitle(Change in working hours following childbirth,size(small)) xtitle(WP mean use flexiplace in%, size(small)) ///
	note("{it:Source: authors' own calculation based on LEEP-B3 (2011/12,2014/15,2018/19); N=3867; based on Table 2,}""{it:Model 3.}", size(small) pos(7)) ///
	plotregion(margin(l+5 r+5))
		
	graph export ${figure}actual_hours_time_varying_fam.png, width(4000) replace
	
** Figure 2 
		
xtreg jazuh i.birth2##c.O_heim $time $famsit , fe vce(cluster paarnr)

	margins r.birth2, at(O_heim=(0(10)100)) level(90) noestimcheck
	marginsplot, graphregion(color(white) lcolor(white)) scheme(s2mono) yline(0) title("")   ylabel (, labsize(small))  xlabel (, labsize(small)) ///
	plot1opts(lpattern(solid) lcolor(black) mcolor(black)) ci1opts(lcolor(gs7) lwidth(thin) mcolor(black))  ///
	ytitle(Change in working hours following childbirth,size(small)) xtitle(WP mean use flexiplace in% (organizations' yearly average), size(small)) ///
	note("{it:Source: authors' own calculation based on LEEP-B3 (2011/12,2014/15,2018/19); N=3867; based on Table 2,}""{it:Model 6. Significance-level 90%.}", size(small) pos(7)) ///
	plotregion(margin(l+5 r+5))
		
	graph export ${figure}actual_hours_time_varying.png, width(4000) replace
	

	
************************************************************************
************** SENSITIVITY ANALYSES ************************************
************************************************************************
	
	

			
	
//Table A4. Split according to average use of flexiplace arrangements

	//Base Models
	xtreg jazuh i.birth2  $time  $famsit if first_O_heim_dic == 0 , fe vce(cluster paarnr)
	eststo tat1
	margins i.birth2, level(90)

	//Base Models
	xtreg jazuh i.birth2  $time  $famsit if first_O_heim_dic == 1 , fe vce(cluster paarnr)
	eststo tat2
	margins i.birth2, level(90)

	//Display of results
	esttab tat1 tat2 using ${table}actual_hours_byuse.rtf, replace  label   /// 
	b(%10.3f)   ///
	nogaps nolines mtitles scalars(r2 r2_w r2_b r2_o)  ///
	compress ///
	star(+ 0.10 * 0.05 ** 0.01 *** 0.001)	
				
	
** Table A5. Split "Men and women should both contribute to the household income"
		
	//Egalitarian Beliefs
	preserve 
	keep if rv_mod >= 4

	//Base Models
	xtreg jazuh i.birth2 $time  $famsit , fe vce(cluster paarnr)
	eststo tat1

	//Organizations 
	xtreg jazuh i.birth2##c.c_first_O_heim  $time $famsit    , fe vce(cluster paarnr)
	eststo tat2

	xtreg jazuh i.birth2##c.c_O_heim  $time $famsit    , fe vce(cluster paarnr)
	eststo tat3

	//Display of results
	esttab  tat1 tat2 tat3    ///
	using ${table}actual_hours_mod1.rtf, replace  label   /// 
	b(%10.3f)   ///
	nogaps nolines mtitles scalars(r2 r2_w r2_b r2_o)  ///
	compress ///
	star(+ 0.10 * 0.05 ** 0.01 *** 0.001)	
	restore 
		
		
	//Traditional Beliefs 
	preserve
	keep if rv_mod <= 3
			
	//Base Models
	xtreg jazuh i.birth2 $time  $famsit , fe vce(cluster paarnr)
	eststo tat1

	//Organizations 
	xtreg jazuh i.birth2##c.c_first_O_heim  $time $famsit    , fe vce(cluster paarnr)
	eststo tat2

	xtreg jazuh i.birth2##c.c_O_heim  $time $famsit    , fe vce(cluster paarnr)
	eststo tat3

	//Display of results
	esttab  tat1 tat2 tat3   ///
	using ${table}actual_hours_mod0.rtf, replace  label   /// 
	b(%10.3f)   ///
	nogaps nolines mtitles scalars(r2 r2_w r2_b r2_o)  ///
	compress ///
	star(+ 0.10 * 0.05 ** 0.01 *** 0.001)	
	restore 
	
	
//Table A6. Split: "A pre-school child is likely to suffer if his or her mother works"
		
	//Egalitarian Beliefs 
	preserve 
	keep if leid >= 4
			
	//Base Models
	xtreg jazuh i.birth2 $time  $famsit , fe vce(cluster paarnr)
	eststo tat1

	//Organizations
	xtreg jazuh i.birth2##c.c_first_O_heim  $time $famsit    , fe vce(cluster paarnr)
	eststo tat2

	xtreg jazuh i.birth2##c.c_O_heim  $time $famsit    , fe vce(cluster paarnr)
	eststo tat3

	//Display of results
	esttab  tat1 tat2 tat3    ///
	using ${table}actual_hours_noleid.rtf, replace  label   /// 
	b(%10.3f)   ///
	nogaps nolines mtitles scalars(r2 r2_w r2_b r2_o)  ///
	compress ///
	star(+ 0.10 * 0.05 ** 0.01 *** 0.001)	
	restore 
	
	//Traditional Beliefs
	preserve
	keep if leid <= 3

	//Base Models
	xtreg jazuh i.birth2 $time  $famsit , fe vce(cluster paarnr)
	eststo tat1

	//Organizations
	xtreg jazuh i.birth2##c.c_first_O_heim  $time $famsit    , fe vce(cluster paarnr)
	eststo tat2

	xtreg jazuh i.birth2##c.c_O_heim  $time $famsit    , fe vce(cluster paarnr)
	eststo tat3

	//Display of results
	esttab  tat1 tat2 tat3   ///
	using ${table}actual_hours_leid.rtf, replace  label   /// 
	b(%10.3f)   ///
	nogaps nolines mtitles scalars(r2 r2_w r2_b r2_o)  ///
	compress ///
	star(+ 0.10 * 0.05 ** 0.01 *** 0.001)	
			
		restore 
	
** Table A7. Split: "It is better for everyone if the father is working and the mother stays at home to care about the children and the household"
		
	//Egalitarian Beliefs
	preserve 
	keep if tradi >= 4
			
	//Base Models
	xtreg jazuh i.birth2 $time  $famsit , fe vce(cluster paarnr)
	eststo tat1

	//Organizations
	xtreg jazuh i.birth2##c.c_first_O_heim  $time $famsit    , fe vce(cluster paarnr)
	eststo tat2

	xtreg jazuh i.birth2##c.c_O_heim  $time $famsit    , fe vce(cluster paarnr)
	eststo tat3

	//Display of results
	esttab  tat1 tat2 tat3    ///
	using ${table}actual_hours_tradi0.rtf, replace  label   /// 
	b(%10.3f)   ///
	nogaps nolines mtitles scalars(r2 r2_w r2_b r2_o)  ///
	compress ///
	star(+ 0.10 * 0.05 ** 0.01 *** 0.001)	
	restore 
	
	
	//Traditional Beliefs
	preserve
	keep if tradi <= 3

	//Base Models
	xtreg jazuh i.birth2 $time  $famsit , fe vce(cluster paarnr)
	eststo tat1

	//Organizations
	xtreg jazuh i.birth2##c.c_first_O_heim  $time $famsit    , fe vce(cluster paarnr)
	eststo tat2

	xtreg jazuh i.birth2##c.c_O_heim  $time $famsit    , fe vce(cluster paarnr)
	eststo tat3

	//Display of results
	esttab  tat1 tat2 tat3   ///
	using ${table}actual_hours_tradi1.rtf, replace  label   /// 
	b(%10.3f)   ///
	nogaps nolines mtitles scalars(r2 r2_w r2_b r2_o)  ///
	compress ///
	star(+ 0.10 * 0.05 ** 0.01 *** 0.001)	
	restore 
